@@ -24,7 +24,10 @@ if sys.platform == "win32":
 	import win32api
 
 import ICCProfile as ICCP
+import colormath
+import cubeiterator as ci
 import localization as lang
+import worker_base
 from imfile import tiff_get_header
 from log import safe_print as log_safe_print
 from meta import name as appname, version
@@ -37,8 +40,18 @@ CALLBACK = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.POINTER(None),
 							ctypes.c_char_p, ctypes.c_ulong, ctypes.c_ulonglong,
 							ctypes.c_char_p, ctypes.c_ulonglong, ctypes.c_bool)
 
+H3D_HEADER = ("3DLT\x01\x00\x00\x00DisplayCAL\x00\x00\x00\x00\x00\x00\x00\x00"
+			  "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00 \x00"
+			  "\x00\x00\x00\x00\x00\x08\x00\x00\x00\x08\x00\x00\x00\x08\x00\x00"
+			  "\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00"
+			  "\x00\x00\x00\x00\x00\x00@\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+			  "\x06\x00\x00\x00\x06")
 
-min_version = (0, 88, 14, 0)
+H3D_PARAMETERS = ("Input_Primaries %.6f %.6f %.6f %.6f %.6f %.6f %.6f %.6f\r\n"
+				  "Input_Range 16 235\r\nOutput_Range 16 235\r\n\x00")
+
+
+min_version = (0, 88, 20, 0)
 
 
 # Search for madTPG on the local PC, connect to the first found instance
@@ -58,7 +71,7 @@ CM_Fail = 5
 _methodnames = ("ConnectEx", "Disable3dlut", "Enable3dlut", "EnterFullscreen",
 				"GetBlackAndWhiteLevel", "GetDeviceGammaRamp",
 				"GetSelected3dlut", "GetVersion",
-				"IsDisableOsdButtonPressed", "IsFullscreen",
+				"IsDisableOsdButtonPressed", "IsFseModeEnabled", "IsFullscreen",
 				"IsStayOnTopButtonPressed",
 				"IsUseFullscreenButtonPressed", "LeaveFullscreen",
 				"SetDisableOsdButton",
@@ -80,6 +93,138 @@ def safe_print(*args):
 		log_safe_print(*args)
 
 
+def icc_device_link_to_madvr(icc_device_link_filename, unity=False,
+							 colorspace=None, hdr=None, logfile=sys.stdout,
+							 convert_video_rgb_to_clut65=False,
+							 append_linear_cal=True):
+	"""
+	Convert ICC device link profile to madVR 256^3 3D LUT using interpolation
+	
+	madvr 3D LUT will be written to:
+	<device link filename without extension> + '.3dlut'
+	
+	"""
+	t = time()
+
+	filename, ext = os.path.splitext(icc_device_link_filename)
+
+	h3d_params = H3D_PARAMETERS
+
+	if filename.endswith(".HDR") or hdr == 2:
+		name = os.path.splitext(filename)[0]
+		h3d_params = "Input_Transfer_Function PQ\r\nOutput_Transfer_Function PQ\r\n" + h3d_params
+	elif filename.endswith(".HDR2SDR") or hdr == 1:
+		name = os.path.splitext(filename)[0]
+		h3d_params = "Input_Transfer_Function PQ\r\n" + h3d_params
+	else:
+		name = filename
+
+	if not colorspace:
+		colorspace = os.path.splitext(name)[1]
+		colorspace = colorspace[1:]
+
+	if not isinstance(colorspace, (list, tuple)):
+		key = {"BT709": "Rec. 709",
+			   "SMPTE_C": "SMPTE-C",
+			   "EBU_PAL": "PAL/SECAM",
+			   "BT2020": "Rec. 2020",
+			   "DCI_P3": "DCI P3 D65"}.get(colorspace)
+		if not key:
+			if not colorspace:
+				safe_print("ERROR - no target color space suffix in filename")
+			else:
+				safe_print("ERROR - invalid target color space:", colorspace)
+			safe_print("Possible target color spaces:",
+					   "BT709, SMPTE_C, EBU_PAL, BT2020, DCI_P3")
+			return False
+
+		rgb_space = colormath.get_rgb_space(key)
+
+		colorspace = colormath.get_rgb_space_primaries_wp_xy(rgb_space)
+
+	rx, ry, gx, gy, bx, by, wx, wy = colorspace
+
+	# Create madVR 3D LUT
+	h3d_stream = StringIO(H3D_HEADER)
+	h3dlut = H3DLUT(h3d_stream, check_lut_size=False)
+	h3dlut.parametersData = h3d_params % (rx, ry, gx, gy, bx, by, wx, wy)
+	h3dlut.write(filename + ".3dlut")
+	raw = open(filename + ".3dlut", "r+b")
+	raw.seek(h3dlut.lutFileOffset)
+	# Make sure no longer needed h3DLUT instance can be garbage collected
+	del h3dlut
+
+	# Lookup 256^3 values through device link and fill madVR cLUT
+	clutres = 256
+	clutmax = clutres - 1.0
+	if unity:
+		logfile.write("Writing unity madVR 3D LUT...\n")
+		prevperc = -1
+		for a in xrange(clutres):
+			for b in xrange(clutres):
+				for c in xrange(clutres):
+					# Optimize for speed
+					B, G, R = chr(c), chr(b), chr(a)
+					raw.write(B + B + G + G + R + R)
+			perc = round(a / clutmax * 100)
+			if perc > prevperc:
+				logfile.write("\r%i%%" % perc)
+				prevperc = perc
+	else:
+		link = ICCP.ICCProfile(icc_device_link_filename)
+		# Need a worker for abort event handling
+		worker = worker_base.WorkerBase()
+		# icclu verbose=0 gives a speed increase
+		xicclu = worker_base.MP_Xicclu(link, scale=clutmax, use_icclu=True,
+									   logfile=logfile,
+									   output_format=("<H", 65535),
+									   reverse=True, output_stream=raw,
+									   convert_video_rgb_to_clut65=convert_video_rgb_to_clut65,
+									   verbose=0, worker=worker)
+		xicclu._in = ci.Cube3D(clutres)
+		logfile.write("Looking up 256^3 input values through device link and "
+					  "writing madVR 3D LUT...\n")
+		xicclu.exit()
+		xicclu.get()
+
+	if append_linear_cal:
+		# Append a MadVR cal1 table to the 3dlut.
+		# This can be used to ensure that the Graphics Card VideoLuts
+		# are correctly setup to match what the 3dLut is expecting.
+		#
+		# Note that the calibration curves are full range, never TV encoded output values
+		#
+		# Format is (little endian):
+		#	4 byte magic number 'cal1'
+		#	4 byte version = 1
+		#	4 byte number per channel entries = 256
+		#	4 byte bytes per entry = 2
+		#	[3][256] 2 byte entry values. Tables are in RGB order
+
+		raw.write("cal1")
+		raw.write(struct.pack('<I', 1))
+		raw.write(struct.pack('<I', 256))
+		raw.write(struct.pack('<I', 2))
+		# Linear (unity) calibration
+		for i in xrange(3):
+			for j in xrange(256):
+				raw.write(struct.pack('<H', j * 257))
+
+	raw.close()
+
+	safe_print("")
+	if unity:
+		msg = "Finished writing unity madVR 3D LUT in"
+	else:
+		msg = "Finished up-interpolating device link and writing madVR 3D LUT in"
+	safe_print(msg, time() - t, "seconds")
+	if filename.endswith(".HDR"):
+		safe_print("Gamut (rx ry gx gy bx by wx wy):",
+				   "%.4f %.4f %.4f %.4f %.4f %.4f %.4f %.4f" %
+				   (rx, ry, gx, gy, bx, by, wx, wy))
+	return True
+
+
 def inet_pton(ip_string):
 	"""
 	inet_pton(string) -> packed IP representation
@@ -348,7 +493,12 @@ class MadTPG(MadTPGBase):
 			value, valuetype = _winreg.QueryValueEx(key, "")
 		except:
 			raise RuntimeError(lang.getstr("madvr.not_found"))
-		self.dllpath = os.path.join(os.path.split(value)[0], "madHcNet32.dll")
+		if platform.architecture()[0] == "64bit":
+			bits = 64
+		else:
+			bits = 32
+		self.dllpath = os.path.join(os.path.split(value)[0],
+									"madHcNet%i.dll" % bits)
 		if not value or not os.path.isfile(self.dllpath):
 			raise OSError(lang.getstr("not_found", self.dllpath))
 		handle = win32api.LoadLibrary(self.dllpath)
@@ -697,6 +847,7 @@ class MadTPG_Net(MadTPGBase):
 						if self.debug:
 							safe_print("MadTPG_Net: Client %s:%i stopped sending" %
 									   addr[:2])
+						send_bye = False
 						break
 					blob += incoming
 					if self.debug:
@@ -713,7 +864,10 @@ class MadTPG_Net(MadTPGBase):
 							if record is None:
 								# Need more data
 								break
-							self._process(record, conn)
+							try:
+								self._process(record, conn)
+							except socket.error, exception:
+								safe_print("MadTPG_Net:", exception)
 		with _lock:
 			self._remove_client(addr, send_bye=addr in self._client_sockets and
 											   send_bye)
@@ -993,7 +1147,7 @@ class MadTPG_Net(MadTPGBase):
 							if self.debug:
 								safe_print("MadTPG_Net: Preventing duplicate connection %s:%i" %
 										   addr[:2])
-							self._remove_client(addr)
+							self._remove_client(addr, False)
 							return
 				self._dispatch_event("on_client_added", (addr, client))
 			else:
@@ -1026,9 +1180,14 @@ class MadTPG_Net(MadTPGBase):
 
 	def get_version(self):
 		""" Return madVR version """
-		return (self._client_socket and
-				self.clients.get(self._client_socket.getpeername(),
-								 {}).get("mvrVersion") or False)
+		try:
+			return (self._client_socket and
+					self.clients.get(self._client_socket.getpeername(),
+									 {}).get("mvrVersion") or False)
+		except socket.error, exception:
+			if self.debug:
+				safe_print("MadTPG_Net:", exception)
+			return False
 
 	def _assemble_hello_params(self):
 		""" Assemble 'hello' packet parameters """
@@ -1061,7 +1220,11 @@ class MadTPG_Net(MadTPGBase):
 		""" Wait until expected reply or timeout. Return reply params or False. """
 		if not isinstance(params, (list, tuple)):
 			params = (params, )
-		addr = conn.getpeername()
+		try:
+			addr = conn.getpeername()
+		except socket.error, exception:
+			safe_print("MadTPG_Net:", exception)
+			return False
 		start = end = time()
 		while end - start < timeout:
 			for reply in self._incoming.get(addr, []):
@@ -1302,9 +1465,12 @@ class MadTPG_Net(MadTPGBase):
 
 	@property
 	def uri(self):
-		return "%s:%s" % (self._client_socket and
-						  self._client_socket.getpeername()[:2] or
-						  ("0.0.0.0", 0))
+		try:
+			addr = self._client_socket and self._client_socket.getpeername()[:2]
+		except socket.error, exception:
+			safe_print("MadTPG_Net:", exception)
+			addr = None
+		return "%s:%s" % (addr or ("0.0.0.0", 0))
 
 
 class MadTPG_Net_Sender(object):
