@@ -123,7 +123,6 @@ config = {"data": ["tests/*.icc"],
 								  "report/*.css",
 								  "report/*.html",
 								  "report/*.js",
-								  "technology_strings-1.7.0.json",
 								  "technology_strings-1.7.1.json",
 								  "test.cal",
 								  "theme/*.png",
@@ -213,7 +212,9 @@ def create_app_symlinks(dist_dir, scripts):
 	toolscripts = filter(lambda script: script != name,
 						 [script for script, desc in scripts])
 	for script, desc in scripts:
-		if script in (name, name + "-apply-profiles"):
+		if (script in (name, name + "-apply-profiles",
+					   name + "-eeColor-to-madVR-converter") or
+			script.endswith("-console")):
 			continue
 		toolname = desc.replace(name, "").strip()
 		toolapp = os.path.join(dist_dir, toolname + ".app")
@@ -317,9 +318,9 @@ def get_data(tgt_dir, key, pkgname=None, subkey=None, excludes=None):
 
 def get_scripts(excludes=None):
 	# It is required that each script has an accompanying .desktop file
-	scripts = []
-	desktopfiles = safe_glob(os.path.join(pydir, "..", "misc",
-							 appname.lower() + "*.desktop"))
+	scripts_with_desc = []
+	scripts = safe_glob(os.path.join(pydir, "..", "scripts",
+									 appname.lower() + "*"))
 	def sortbyname(a, b):
 		a, b = [os.path.splitext(v)[0] for v in (a, b)]
 		if a > b:
@@ -328,17 +329,22 @@ def get_scripts(excludes=None):
 			return -1
 		else:
 			return 0
-	desktopfiles.sort(sortbyname)
-	for desktopfile in desktopfiles:
-		if desktopfile.startswith("z-"):
+	scripts.sort(sortbyname)
+	for script in scripts:
+		script = os.path.basename(script)
+		if script == appname.lower() + "-apply-profiles-launcher":
 			continue
-		cfg = ConfigParser()
-		cfg.read(desktopfile)
-		script = cfg.get("Desktop Entry", "Exec").split()[0]
+		desktopfile = os.path.join(pydir, "..", "misc", script + ".desktop")
+		if os.path.isfile(desktopfile):
+			cfg = ConfigParser()
+			cfg.read(desktopfile)
+			script = cfg.get("Desktop Entry", "Exec").split()[0]
+			desc = cfg.get("Desktop Entry", "Name").decode("UTF-8")
+		else:
+			desc = ""
 		if not filter(lambda exclude: fnmatch(script, exclude), excludes or []):
-			scripts.append((script,
-							cfg.get("Desktop Entry", "Name").decode("UTF-8")))
-	return scripts
+			scripts_with_desc.append((script, desc))
+	return scripts_with_desc
 
 
 def setup():
@@ -532,9 +538,15 @@ def setup():
 			if is_rpm_build:
 				doc = os.path.join(os.path.sep, "usr", doc)
 
-	# Use bundled CA file
-	if sdist or do_py2app or do_py2exe:
-		config["package_data"][name].append("cacert.pem")
+	# Use CA file from certifi project
+	if do_py2app or do_py2exe:
+		import certifi
+		cacert = certifi.where()
+		if cacert:
+			shutil.copyfile(cacert, os.path.join(pydir, "cacert.pem"))
+			config["package_data"][name].append("cacert.pem")
+		else:
+			print "WARNING: cacert.pem from certifi project not found!"
 
 	# on Mac OS X and Windows, we want data files in the package dir
 	# (package_data will be ignored when using py2exe)
@@ -702,6 +714,11 @@ def setup():
 				data_files.append((os.path.join(os.path.dirname(data), "icons", 
 											 "hicolor", dname, "apps"), 
 								   desktopicons))
+	if do_py2app:
+		data_files.append((os.path.join(data, "scripts"),
+						   [os.path.join(pydir, "..", "scripts",
+										 name.lower() +
+										 "-eecolor-to-madvr-converter")]))
 
 	sources = [os.path.join(name, "RealDisplaySizeMM.c")]
 	if sys.platform == "win32":
@@ -886,8 +903,12 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 	if do_py2exe:
 		import wx
 		from winmanifest_util import getmanifestxml
+		if platform.architecture()[0] == "64bit":
+			arch = "amd64"
+		else:
+			arch = "x86"
 		manifest_xml = getmanifestxml(os.path.join(pydir, "..", "misc", 
-			name + (".exe.VC90.manifest" if hasattr(sys, "version_info") and 
+			name + (".exe.%s.VC90.manifest" % arch if hasattr(sys, "version_info") and 
 			sys.version_info[:2] >= (2,6) else ".exe.manifest")))
 		tmp_scripts_dir = os.path.join(basedir, "build", "temp.scripts")
 		if not os.path.isdir(tmp_scripts_dir):
@@ -905,25 +926,31 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 			"other_resources": [(24, 1, manifest_xml)],
 			"copyright": u"© %s %s" % (strftime("%Y"), author),
 			"description": desc
-		}) for script, desc in scripts]
+		}) for script, desc in filter(lambda (script, desc):
+									  script != appname.lower() +
+									  "-eecolor-to-madvr-converter" and
+									  not script.endswith("-console"), scripts)]
+
 		# Add profile loader launcher
 		attrs["windows"].append(Target(**{
 			"script": os.path.join(tmp_scripts_dir,
 								   script2pywname(apply_profiles_launcher[0])),
 			"icon_resources": [(1, os.path.join(pydir, "theme", "icons", 
-												appname.lower() + "-apply-profiles" +
+												appname + "-apply-profiles" +
 												".ico"))],
 			"other_resources": [(24, 1, manifest_xml)],
 			"copyright": u"© %s %s" % (strftime("%Y"), author),
 			"description": apply_profiles_launcher[1]
 		}))
-		console_scripts = [name + "-VRML-to-X3D-converter"]
+
+		# Programs that can run with and without GUI
+		console_scripts = [name + "-VRML-to-X3D-converter"]  # No "-console" suffix!
 		for console_script in console_scripts:
 			console_script_path = os.path.join(tmp_scripts_dir,
 											   console_script + "-console")
 			if not os.path.isfile(console_script_path):
 				shutil.copy(os.path.join(basedir, "scripts",
-										 console_script.lower()),
+										 console_script.lower() + "-console"),
 							console_script_path)
 		attrs["console"] = [Target(**{
 			"script": os.path.join(tmp_scripts_dir,
@@ -937,8 +964,11 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 		}) for script, desc in filter(lambda (script, desc):
 									  script2pywname(script) in console_scripts,
 									  scripts)]
+
+		# Programs without GUI
 		attrs["console"].append(Target(**{
-			"script": os.path.join(basedir, "scripts", "eecolor_to_madvr"),
+			"script": os.path.join(tmp_scripts_dir,
+								   appname + "-eeColor-to-madVR-converter"),
 			"icon_resources": [(1, os.path.join(pydir, "theme", "icons", 
 												appname + "-3DLUT-maker.ico"))],
 			"other_resources": [(24, 1, manifest_xml)],
@@ -946,6 +976,7 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 			"description": "Convert eeColor 65^3 to madVR 256^3 3D LUT "
 						   "(video levels in, video levels out)"
 		}))
+
 		dist_dir = os.path.join(pydir, "..", "dist", "py2exe.%s-py%s" % 
 								(get_platform(), sys.version[:3]), name + 
 								"-" + version)
@@ -1129,7 +1160,6 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 					"pnp.ids",
 					"quirk.json",
 					"linear.cal",
-					"technology_strings-1.7.0.json",
 					"technology_strings-1.7.1.json",
 					"test.cal"
 				]:
@@ -1220,7 +1250,8 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 		manifest_in.extend(["include LICENSE.txt", "include MANIFEST", 
 							"include MANIFEST.in", "include README.html", 
 							"include README-fr.html", "include CHANGES.html",
-							"include *.pyw", "include use-distutils"])
+							"include %s*.pyw" % name, "include %s-*.pyw" % name,
+							"include %s-*.py" % name, "include use-distutils"])
 		manifest_in.append("include " + os.path.basename(sys.argv[0]))
 		manifest_in.append("include " + 
 						   os.path.splitext(os.path.basename(sys.argv[0]))[0] + 
