@@ -322,7 +322,8 @@ class ReportFrame(BaseFrame):
 					if event:
 						v = int(not self.chart_white or not "RGB" in values)
 						setcfg("measurement_report.whitepoint.simulate", v)
-						setcfg("measurement_report.whitepoint.simulate.relative", v)
+						setcfg("measurement_report.whitepoint.simulate.relative",
+							   int("LAB" in values))
 			if not values:
 				if chart:
 					show_result_dialog(lang.getstr("error.testchart.missing_fields",
@@ -476,7 +477,17 @@ class ReportFrame(BaseFrame):
 													   % odata, self)
 									self.set_profile_ctrl_path(which)
 									return
-								self.XYZbpout = odata[0]
+								if odata[0][1]:
+									# Got above zero blackpoint from lookup
+									self.XYZbpout = odata[0]
+								else:
+									# Got zero blackpoint from lookup.
+									# Try chardata instead.
+									XYZbp = profile.get_chardata_bkpt()
+									if XYZbp:
+										self.XYZbpout = XYZbp
+									else:
+										self.XYZbpout = [0, 0, 0]
 					else:
 						# Profile selection has not changed
 						# Restore cached XYZbp values
@@ -842,7 +853,7 @@ class ReportFrame(BaseFrame):
 			use_sim_profile = getcfg("measurement_report.use_simulation_profile")
 		sim_profile = getattr(self, "simulation_profile", None)
 		enable = False
-		if sim_profile:
+		if use_sim_profile and sim_profile:
 			v = int(sim_profile.profileClass == "prtr")
 			setcfg("measurement_report.whitepoint.simulate", v)
 			setcfg("measurement_report.whitepoint.simulate.relative", v)
@@ -852,7 +863,7 @@ class ReportFrame(BaseFrame):
 				isinstance(sim_profile.tags.rTRC, ICCP.CurveType)):
 				tf = sim_profile.tags.rTRC.get_transfer_function(outoffset=1.0)
 				if update_trc or self.XYZbpin == self.XYZbpout:
-					# Use only BT.1886 black output offset
+					# Use only BT.1886 black output offset or not
 					setcfg("measurement_report.apply_black_offset",
 						   int(tf[0][1] not in (-240, -709) and
 							   (not tf[0][0].startswith("Gamma") or tf[1] < .95) and
@@ -877,6 +888,10 @@ class ReportFrame(BaseFrame):
 				self.mr_update_trc_controls()
 				enable = (tf[0][1] not in (-240, -709) and
 						  self.XYZbpin != self.XYZbpout)
+			elif update_trc:
+				enable = self.XYZbpin != self.XYZbpout
+				setcfg("measurement_report.apply_black_offset", int(enable))
+				setcfg("measurement_report.apply_trc", 0)
 		self.apply_black_offset_ctrl.Enable(use_sim_profile and enable)
 		self.mr_update_main_controls()
 
