@@ -1,3 +1,4 @@
+// !!!DO NOT CHANGE NEUTRAL ENTRIES!!!
 var CRITERIA_RULES_NEUTRAL = [
 		// description, [[R, G, B],...], DELTA_[E|L|C|H]_[MAX|MED|MAD|AVG|STDDEV], max, recommended, [CIE[76|94|00]|CMC11|CMC21]
 		["Measured vs. assumed target whitepoint ΔE*76", ['WHITEPOINT_MvsA'], DELTA_E_MAX, null, null, CIE76],
@@ -37,14 +38,14 @@ CRITERIA_RULES_DEFAULT[1][4] = 1; // Measured vs. assumed whitepoint ΔE*94 reco
 CRITERIA_RULES_DEFAULT[2][3] = 2; // Measured vs. assumed whitepoint ΔE*00 nominal
 CRITERIA_RULES_DEFAULT[2][4] = 1; // Measured vs. assumed whitepoint ΔE*00 recommended
 
-CRITERIA_RULES_DEFAULT[3][3] = 3; // Measured vs. profile whitepoint ΔE*76 nominal
-CRITERIA_RULES_DEFAULT[3][4] = 1.5; // Measured vs. profile whitepoint ΔE*76 recommended
+//CRITERIA_RULES_DEFAULT[3][3] = 2; // Measured vs. profile whitepoint ΔE*76 nominal
+CRITERIA_RULES_DEFAULT[3][4] = 1; // Measured vs. profile whitepoint ΔE*76 recommended
 
-CRITERIA_RULES_DEFAULT[4][3] = 3; // Measured vs. profile whitepoint ΔE*94 nominal
-CRITERIA_RULES_DEFAULT[4][4] = 1.5; // Measured vs. profile whitepoint ΔE*94 recommended
+//CRITERIA_RULES_DEFAULT[4][3] = 2; // Measured vs. profile whitepoint ΔE*94 nominal
+CRITERIA_RULES_DEFAULT[4][4] = 1; // Measured vs. profile whitepoint ΔE*94 recommended
 
-CRITERIA_RULES_DEFAULT[5][3] = 3; // Measured vs. profile whitepoint ΔE*00 nominal
-CRITERIA_RULES_DEFAULT[5][4] = 1.5; // Measured vs. profile whitepoint ΔE*00 recommended
+//CRITERIA_RULES_DEFAULT[5][3] = 2; // Measured vs. profile whitepoint ΔE*00 nominal
+CRITERIA_RULES_DEFAULT[5][4] = 1; // Measured vs. profile whitepoint ΔE*00 recommended
 
 CRITERIA_RULES_DEFAULT[6][3] = 3; // Average ΔE*76 nominal
 CRITERIA_RULES_DEFAULT[6][4] = 1.5; // Average ΔE*76 recommended
@@ -64,6 +65,18 @@ CRITERIA_RULES_DEFAULT[10][4] = 3; // Maximum ΔE*94 recommended
 CRITERIA_RULES_DEFAULT[11][3] = 4; // Maximum ΔE*00 nominal
 CRITERIA_RULES_DEFAULT[11][4] = 3; // Maximum ΔE*00 recommended
 
+CRITERIA_RULES_DEFAULT = CRITERIA_RULES_DEFAULT.concat(
+	[
+		["Measured vs. assumed target whitepoint ΔICtCp", ['WHITEPOINT_MvsA'], DELTA_E_MAX, 2, 1, ICTCP],
+		["Measured vs. display profile whitepoint ΔICtCp", ['WHITEPOINT_MvsP'], DELTA_E_MAX, null, 1, ICTCP],
+		["Average ΔICtCp", [], DELTA_E_AVG, 1.5, 1, ICTCP],
+		["Maximum ΔICtCp", [], DELTA_E_MAX, 5, 3, ICTCP],
+		["Median ΔICtCp", [], DELTA_E_MED, null, null, ICTCP],
+		["Median absolute deviation ΔICtCp", [], DELTA_E_MAD, null, null, ICTCP],
+		["Standard deviation ΔICtCp", [], DELTA_E_STDDEV, null, null, ICTCP]
+	]
+);
+
 var CRITERIA_RULES_RGB = CRITERIA_RULES_DEFAULT.clone().concat(
 		[
 			["Gamma maximum", [], GAMMA_MAX],
@@ -80,12 +93,15 @@ var CRITERIA_RULES_RGB = CRITERIA_RULES_DEFAULT.clone().concat(
 			["RGB gray balance (>= 1% luminance) average absolute ΔC*76", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, CIE76],
 			["RGB gray balance (>= 1% luminance) combined Δa*76 and Δb*76 range", window.CRITERIA_GRAYSCALE, DELTA_A_B_RANGE, 2.0, 1.5, CIE76],
 			["RGB gray balance (>= 1% luminance) maximum ΔC*76", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, CIE76],
-			["RGB gray balance (>= 1% luminance) average absolute ΔC*94", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, CIE94],
+			["RGB gray balance (>= 1% luminance) average absolute weighted ΔC*94", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, CIE94],
 			["RGB gray balance (>= 1% luminance) combined Δa*94 and Δb*94 range", window.CRITERIA_GRAYSCALE, DELTA_A_B_RANGE, 2.0, 1.5, CIE94],
-			["RGB gray balance (>= 1% luminance) maximum ΔC*94", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, CIE94],
-			["RGB gray balance (>= 1% luminance) average absolute ΔC*00", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, CIE00],
+			["RGB gray balance (>= 1% luminance) maximum weighted ΔC*94", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, CIE94],
+			["RGB gray balance (>= 1% luminance) average absolute weighted ΔC'00", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, CIE00],
 			["RGB gray balance (>= 1% luminance) combined Δa*00 and Δb*00 range", window.CRITERIA_GRAYSCALE, DELTA_A_B_RANGE, 2.0, 1.5, CIE00],
-			["RGB gray balance (>= 1% luminance) maximum ΔC*00", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, CIE00]
+			["RGB gray balance (>= 1% luminance) maximum weighted ΔC'00", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, CIE00],
+			["RGB gray balance (>= 1% luminance) average absolute ΔC CtCp", window.CRITERIA_GRAYSCALE, DELTA_C_AVG, 1.0, 0.5, ICTCP],
+			["RGB gray balance (>= 1% luminance) combined ΔCt and ΔCp range", window.CRITERIA_GRAYSCALE, DELTA_A_B_RANGE, 2.0, 1.5, ICTCP],
+			["RGB gray balance (>= 1% luminance) maximum ΔC CtCp", window.CRITERIA_GRAYSCALE, DELTA_C_MAX, null, null, ICTCP]
 		]
 	),
 	CRITERIA_RULES_CMYK = CRITERIA_RULES_DEFAULT.clone(),
@@ -323,3 +339,75 @@ CRITERIA_IDEALLIANCE_2009.rules[11][3] = 6; // Maximum ΔE*00 nominal
 
 CRITERIA_IDEALLIANCE_2013.rules[8][3] = 4; // Average ΔE*00 nominal
 CRITERIA_IDEALLIANCE_2013.rules[11][3] = 6.5; // Maximum ΔE*00 nominal
+
+comparison_criteria['RGB_HUE_CHROMA_ONLY'] = {
+		fields_match: ['RGB_R', 'RGB_G', 'RGB_B'],
+		fields_compare: ['LAB_L', 'LAB_A', 'LAB_B'],
+		id: "RGB_HUE_CHROMA_ONLY",
+		name: "Hue & chroma only",
+		passtext: "Nominal tolerance passed",
+		failtext: "Nominal tolerance exceeded",
+		passrecommendedtext: "Recommended tolerance passed",
+		failrecommendedtext: null,
+		delta_calc_method: CIE00, // delta calculation method for overview
+		lock_delta_calc_method: false,
+		warn_deviation: null,
+		rules: [
+			["Measured vs. assumed target whitepoint ΔC*76", ['WHITEPOINT_MvsA'], DELTA_C_MAX, 2, 1, CIE76],
+			["Measured vs. assumed target whitepoint weighted ΔC*94", ['WHITEPOINT_MvsA'], DELTA_C_MAX, 2, 1, CIE94],
+			["Measured vs. assumed target whitepoint weighted ΔC'00", ['WHITEPOINT_MvsA'], DELTA_C_MAX, 2, 1, CIE00],
+			["Measured vs. assumed target whitepoint ΔC CtCp", ['WHITEPOINT_MvsA'], DELTA_C_MAX, 2, 1, ICTCP],
+			["Measured vs. assumed target whitepoint ΔH*76", ['WHITEPOINT_MvsA'], DELTA_H_MAX, 2, 1, CIE76],
+			["Measured vs. assumed target whitepoint weighted ΔH*94", ['WHITEPOINT_MvsA'], DELTA_H_MAX, 2, 1, CIE94],
+			["Measured vs. assumed target whitepoint weighted ΔH'00", ['WHITEPOINT_MvsA'], DELTA_H_MAX, 2, 1, CIE00],
+			["Measured vs. assumed target whitepoint ΔH CtCp", ['WHITEPOINT_MvsA'], DELTA_H_MAX, 2, 1, ICTCP],
+			["Measured vs. display profile whitepoint ΔC*76", ['WHITEPOINT_MvsP'], DELTA_C_MAX, null, 1, CIE76],
+			["Measured vs. display profile whitepoint weighted ΔC*94", ['WHITEPOINT_MvsP'], DELTA_C_MAX, null, 1, CIE94],
+			["Measured vs. display profile whitepoint weighted ΔC'00", ['WHITEPOINT_MvsP'], DELTA_C_MAX, null, 1, CIE00],
+			["Measured vs. display profile whitepoint ΔC CtCp", ['WHITEPOINT_MvsP'], DELTA_C_MAX, null, 1, ICTCP],
+			["Measured vs. display profile whitepoint ΔH*76", ['WHITEPOINT_MvsP'], DELTA_H_MAX, null, 1, CIE76],
+			["Measured vs. display profile whitepoint weighted ΔH*94", ['WHITEPOINT_MvsP'], DELTA_H_MAX, null, 1, CIE94],
+			["Measured vs. display profile whitepoint weighted ΔH'00", ['WHITEPOINT_MvsP'], DELTA_H_MAX, null, 1, CIE00],
+			["Measured vs. display profile whitepoint ΔH CtCp", ['WHITEPOINT_MvsP'], DELTA_H_MAX, null, 1, ICTCP],
+			["Average ΔC*76", [], DELTA_C_AVG, 3, 1.5, CIE76],
+			["Average weighted ΔC*94", [], DELTA_C_AVG, 1.5, 1, CIE94],
+			["Average weighted ΔC'00", [], DELTA_C_AVG, 1.5, 1, CIE00],
+			["Average ΔC CtCp", [], DELTA_C_AVG, 1.5, 1, ICTCP],
+			["Average ΔH*76", [], DELTA_H_AVG, 3, 1.5, CIE76],
+			["Average weighted ΔH*94", [], DELTA_H_AVG, 1.5, 1, CIE94],
+			["Average weighted ΔH'00", [], DELTA_H_AVG, 1.5, 1, CIE00],
+			["Average ΔH CtCp", [], DELTA_H_AVG, 1.5, 1, ICTCP],
+			["Maximum ΔC*76", [], DELTA_C_MAX, 6, 4, CIE76],
+			["Maximum weighted ΔC*94", [], DELTA_C_MAX, 4, 3, CIE94],
+			["Maximum weighted ΔC'00", [], DELTA_C_MAX, 4, 3, CIE00],
+			["Maximum ΔC CtCp", [], DELTA_C_MAX, 5, 3, ICTCP],
+			["Maximum ΔH*76", [], DELTA_H_MAX, 6, 4, CIE76],
+			["Maximum weighted ΔH*94", [], DELTA_H_MAX, 4, 3, CIE94],
+			["Maximum weighted ΔH'00", [], DELTA_H_MAX, 4, 3, CIE00],
+			["Maximum ΔH CtCp", [], DELTA_H_MAX, 5, 3, ICTCP],
+			["Median ΔC*76", [], DELTA_C_MED, null, null, CIE76],
+			["Median weighted ΔC*94", [], DELTA_C_MED, null, null, CIE94],
+			["Median weighted ΔC'00", [], DELTA_C_MED, null, null, CIE00],
+			["Median ΔC CtCp", [], DELTA_C_MED, null, null, ICTCP],
+			["Median ΔH*76", [], DELTA_H_MED, null, null, CIE76],
+			["Median weighted ΔH*94", [], DELTA_H_MED, null, null, CIE94],
+			["Median weighted ΔH'00", [], DELTA_H_MED, null, null, CIE00],
+			["Median ΔH CtCp", [], DELTA_H_MED, null, null, ICTCP],
+			["Median absolute deviation ΔC*76", [], DELTA_C_MAD, null, null, CIE76],
+			["Median absolute deviation weighted ΔC*94", [], DELTA_C_MAD, null, null, CIE94],
+			["Median absolute deviation weighted ΔC'00", [], DELTA_C_MAD, null, null, CIE00],
+			["Median absolute deviation ΔC CtCp", [], DELTA_C_MAD, null, null, ICTCP],
+			["Median absolute deviation ΔH*76", [], DELTA_H_MAD, null, null, CIE76],
+			["Median absolute deviation weighted ΔH*94", [], DELTA_H_MAD, null, null, CIE94],
+			["Median absolute deviation weighted ΔH'00", [], DELTA_H_MAD, null, null, CIE00],
+			["Median absolute deviation ΔH CtCp", [], DELTA_H_MAD, null, null, ICTCP],
+			["Standard deviation ΔC*76", [], DELTA_C_STDDEV, null, null, CIE76],
+			["Standard deviation weighted ΔC*94", [], DELTA_C_STDDEV, null, null, CIE94],
+			["Standard deviation weighted ΔC'00", [], DELTA_C_STDDEV, null, null, CIE00],
+			["Standard deviation ΔC CtCp", [], DELTA_C_STDDEV, null, null, ICTCP],
+			["Standard deviation ΔH*76", [], DELTA_H_STDDEV, null, null, CIE76],
+			["Standard deviation weighted ΔH*94", [], DELTA_H_STDDEV, null, null, CIE94],
+			["Standard deviation weighted ΔH'00", [], DELTA_H_STDDEV, null, null, CIE00],
+			["Standard deviation ΔH CtCp", [], DELTA_H_STDDEV, null, null, ICTCP]
+		]
+	};
